@@ -1,4 +1,4 @@
-#' @method plot grm
+#' @export plot.grm
 #' @title S3 Plotting Graphical Model Check
 #' @description S3 plotting Method for object of class\code{"grm"}
 #' @param x object of class\code{"grm"}
@@ -8,7 +8,7 @@
 #' @param ci numeric defining confidence intervall for point estimator
 #' @param main see \code{\link{plot}}
 #' @param col.error vector of colors for error bars
-
+#' @param col.diag color for the diagonal of the plot
 #' @param itemNames logical wether to plot itemnames
 #' @param cex.names magnification factor for itemnames
 #' @param type see \code{\link{plot}}
@@ -19,7 +19,7 @@
 #' @param cex.axis see \code{\link{plot}}
 #' @param ... other parameters passed to plot
 ########################### hier die plot method für grm #############################
-plot.grm<-function(x, xymin=NULL, xymax=NULL, ci=2, main=NULL, col.error="blue", itemNames=FALSE, cex.names=.8, type="b", xlab=NULL, ylab=NULL, pch=43, las=3, cex.axis = 0.5, ...){  
+plot.grm<-function(x, xymin=NULL, xymax=NULL, ci=2, main=NULL, col.error="blue", col.diag="red", itemNames=TRUE, cex.names=.8, type="b", xlab=NULL, ylab=NULL, pch=43, las=3, cex.axis = 0.5, ...){  
   
   if(length(main)==0){main<-deparse(substitute(x))}
   
@@ -27,15 +27,21 @@ plot.grm<-function(x, xymin=NULL, xymax=NULL, ci=2, main=NULL, col.error="blue",
   if (length(x)==2){
     subsamp_names <- names(x)
     
-    Itemnames<-names(x[[1]]$parameter[,dim(x[[2]]$parameter)[2]])
-    X<-x[[subsamp_names[1]]]$parameter[,dim(x[[ subsamp_names[1] ]]$parameter)[2]]
-    Y<-x[[subsamp_names[2]]]$parameter[,dim(x[[ subsamp_names[2] ]]$parameter)[2]]
-    XS<-x[[ subsamp_names[1] ]]$SE[,dim(x[[ subsamp_names[1] ]]$SE)[2]]
-    YS<-x[[ subsamp_names[2] ]]$SE[,dim(x[[ subsamp_names[2] ]]$SE)[2]]
+#    Itemnames<-names(x[[1]]$threshold[,dim(x[[2]]$threshold)[2]])
+    Itemnames <- rownames(x[[1]]$threshold)
+#     X<-x[[subsamp_names[1]]]$threshold[,dim(x[[ subsamp_names[1] ]]$threshold)[2]]
+#     Y<-x[[subsamp_names[2]]]$parameter[,dim(x[[ subsamp_names[2] ]]$parameter)[2]]
+    X<-x[[subsamp_names[1]]]$sigma
+    Y<-x[[subsamp_names[2]]]$sigma
+    
+#    XS<-x[[ subsamp_names[1] ]]$SE[,dim(x[[ subsamp_names[1] ]]$SE)[2]]
+#    YS<-x[[ subsamp_names[2] ]]$SE[,dim(x[[ subsamp_names[2] ]]$SE)[2]]
+    XS<-x[[ subsamp_names[1] ]]$SEsigma
+    YS<-x[[ subsamp_names[2] ]]$SEsigma
 
     ##### plotingrange festlegen mit leerplot
-    if(length(xymax)==0){xymax<-max(c(max(X),max(Y))) + 3*(max(c(max(XS),max(YS))))}
-    if(length(xymin)==0){xymin<-min(c(min(X),min(Y))) - 3*(max(c(max(XS),max(YS))))}
+    if(length(xymax)==0){xymax<-(round((max(c(max(X),max(Y))) + 3*(max(c(max(XS),max(YS)))))*10))/10}
+    if(length(xymin)==0){xymin<-(round((min(c(min(X),min(Y))) - 3*(max(c(max(XS),max(YS)))))*10))/10}
     
     xx<-c(xymin,xymax); yy<-c(xymin,xymax)
     if (length(xlab)==0) {xlab <- subsamp_names[1]}
@@ -55,7 +61,7 @@ plot.grm<-function(x, xymin=NULL, xymax=NULL, ci=2, main=NULL, col.error="blue",
     if (itemNames==TRUE){pch=""}
     if (itemNames==TRUE){text(X,Y,Itemnames,cex=cex.names,...)}
     points(X,Y,pch=pch,...) 
-    abline(0,1,col="red",...) 
+    abline(0,1,col=col.diag,...) 
     for (i in 1: length(X)){ eli(X[i],Y[i],XS[i]*ci,YS[i]*ci) }
 }
   
